@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2007   Alex Shulgin
+ * Copyright (C) 2007,2008   Alex Shulgin
  *
- * This file is part of png++ the C++ wrapper for libpng.  Png++ is free
+ * This file is part of png++ the C++ wrapper for libpng.  PNG++ is free
  * software; the exact copying conditions are as follows:
  *
  * Redistribution and use in source and binary forms, with or without
@@ -38,9 +38,9 @@ namespace png
 {
 
     /**
-     * \brief PNG writer class template.  This is the low-level writing
-     * interface -- use image class or generator class to actually
-     * write images.
+     * \brief PNG writer class template.  This is the low-level
+     * writing interface--use image class or generator class to
+     * actually write images.
      *
      * The \c ostream template parameter specifies the type of output
      * stream to work with.  The \c ostream class should implement the
@@ -88,7 +88,7 @@ namespace png
 
         void write_png() const
         {
-            if (setjmp(m_png->jmpbuf))
+            if (setjmp(png_jmpbuf(m_png)))
             {
                 throw error(m_error);
             }
@@ -103,7 +103,7 @@ namespace png
          */
         void write_info() const
         {
-            if (setjmp(m_png->jmpbuf))
+            if (setjmp(png_jmpbuf(m_png)))
             {
                 throw error(m_error);
             }
@@ -115,7 +115,7 @@ namespace png
          */
         void write_row(byte* bytes)
         {
-            if (setjmp(m_png->jmpbuf))
+            if (setjmp(png_jmpbuf(m_png)))
             {
                 throw error(m_error);
             }
@@ -127,7 +127,7 @@ namespace png
          */
         void write_end_info() const
         {
-            if (setjmp(m_png->jmpbuf))
+            if (setjmp(png_jmpbuf(m_png)))
             {
                 throw error(m_error);
             }
